.. include global.rst

`pyvips` -- Image processing with libvips
=========================================

.. module:: pyvips
    :synopsis: Interface to the libvips image processing library.
.. moduleauthor:: John Cupitt <jcupitt@gmail.com>
.. moduleauthor:: Kleis Auke Wolthuizen <info@kleisauke.nl>

Contents
--------

.. toctree::
   :maxdepth: 2

   README
   intro
   vimage
   base
   error
   enums
   vconnection
   vsource
   vtarget
   vsourcecustom
   vtargetcustom
   vinterpolate
   gvalue
   gobject
   voperation
   vobject

Indicies
--------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
